==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QConicalGradient_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qbrush.h>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qpair.h>
#include <QtCore/qpoint.h>
#include <QtGui/qcolor.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QConicalGradient(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QConicalGradient")
    QConicalGradient *_ptr = reinterpret_cast<QConicalGradient *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QConicalGradient()
void __qt_construct_QConicalGradient_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient()")
    Q_UNUSED(__java_arguments)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QConicalGradient(QPointF,qreal)
void __qt_construct_QConicalGradient_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient(QPointF,qreal)")
    jobject center0 = __java_arguments[0].l;
    const QPointF& __qt_center0 = qtjambi_cast<const QPointF& >(__jni_env, center0);
    jdouble startAngle1 = __java_arguments[1].d;
    Q_UNUSED(startAngle1)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient(__qt_center0, static_cast<qreal>(startAngle1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QConicalGradient(qreal,qreal,qreal)
void __qt_construct_QConicalGradient_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient(qreal,qreal,qreal)")
    jdouble cx0 = __java_arguments[0].d;
    Q_UNUSED(cx0)
    jdouble cy1 = __java_arguments[1].d;
    Q_UNUSED(cy1)
    jdouble startAngle2 = __java_arguments[2].d;
    Q_UNUSED(startAngle2)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient(static_cast<qreal>(cx0), static_cast<qreal>(cy1), static_cast<qreal>(startAngle2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QConicalGradient
void __qt_destruct_QConicalGradient(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QConicalGradient")
    reinterpret_cast<QConicalGradient*>(ptr)->~QConicalGradient();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QConicalGradient::QConicalGradient()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_0, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::QConicalGradient(QPointF,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2Lio_qt_core_QPointF_2D)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject center0,
 jdouble startAngle1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient(QPointF,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = center0;
        arguments[1].d = startAngle1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_1, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::QConicalGradient(qreal,qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2DDD)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble cx0,
 jdouble cy1,
 jdouble startAngle2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient(qreal,qreal,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].d = cx0;
        arguments[1].d = cy1;
        arguments[2].d = startAngle2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_2, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::angle()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_angle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::angle()const", __qt_this)
        qreal __qt_return_value = __qt_this->angle();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QConicalGradient::center()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_center_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::center()const", __qt_this)
        QPointF __qt_return_value = __qt_this->center();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QConicalGradient::setAngle(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setAngle_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble angle0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setAngle(qreal)", __qt_this)
        __qt_this->setAngle(static_cast<qreal>(angle0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::setCenter(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setCenter_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID center0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setCenter(QPointF)", __qt_this)
        const QPointF& __qt_center0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(center0);
        __qt_this->setCenter(__qt_center0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::setCenter(qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setCenter_1native_1qreal_1qreal__JDD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble x0,
 jdouble y1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setCenter(qreal,qreal)", __qt_this)
        __qt_this->setCenter(static_cast<qreal>(x0), static_cast<qreal>(y1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QConicalGradient(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QConicalGradient* copy = static_cast<const QConicalGradient*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QConicalGradient(copy->center(), copy->angle());
    }else{
        return new(placement) QConicalGradient();
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QConicalGradient(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QConicalGradient>("QConicalGradient", "io/qt/gui/QConicalGradient");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QConicalGradient, {
        ConstructorInfo(&__qt_construct_QConicalGradient_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QConicalGradient_1, "Lio/qt/core/QPointF;D")
       ,ConstructorInfo(&__qt_construct_QConicalGradient_2, "DDD")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QConicalGradient);
    registerMetaType<QConicalGradient>("QConicalGradient", &custom_constructor_QConicalGradient);
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QGradient), typeId, [](void *ptr, qintptr& offset) -> bool {
            QGradient *object = reinterpret_cast<QGradient *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type() == QGradient::ConicalGradient;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QConicalGradient_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qbrush.h>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qpair.h>
#include <QtCore/qpoint.h>
#include <QtGui/qcolor.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QConicalGradient(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QConicalGradient")
    QConicalGradient *_ptr = reinterpret_cast<QConicalGradient *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QConicalGradient()
void __qt_construct_QConicalGradient(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient()")
    Q_UNUSED(__java_arguments)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QConicalGradient::QConicalGradient()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QConicalGradient(QConicalGradient)
void __qt_construct_QConicalGradient_cref_QConicalGradient(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient(QConicalGradient)")
    jobject other0 = __java_arguments[0].l;
    const QConicalGradient& __qt_other0 = qtjambi_cast<const QConicalGradient& >(__jni_env, other0);
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QConicalGradient::QConicalGradient(QConicalGradient)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2Lio_qt_gui_QConicalGradient_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient(QConicalGradient)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_cref_QConicalGradient, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QConicalGradient(QPointF,qreal)
void __qt_construct_QConicalGradient_cref_QPointF_qreal(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient(QPointF,qreal)")
    jobject center0 = __java_arguments[0].l;
    const QPointF& __qt_center0 = qtjambi_cast<const QPointF& >(__jni_env, center0);
    jdouble startAngle1 = __java_arguments[1].d;
    Q_UNUSED(startAngle1)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient(__qt_center0, static_cast<qreal>(startAngle1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QConicalGradient::QConicalGradient(QPointF,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2Lio_qt_core_QPointF_2D)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject center0,
 jdouble startAngle1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient(QPointF,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = center0;
        arguments[1].d = startAngle1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_cref_QPointF_qreal, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QConicalGradient(qreal,qreal,qreal)
void __qt_construct_QConicalGradient_qreal_qreal_qreal(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QConicalGradient(qreal,qreal,qreal)")
    jdouble cx0 = __java_arguments[0].d;
    Q_UNUSED(cx0)
    jdouble cy1 = __java_arguments[1].d;
    Q_UNUSED(cy1)
    jdouble startAngle2 = __java_arguments[2].d;
    Q_UNUSED(startAngle2)
    QConicalGradient *__qt_this = new(__qtjambi_ptr) QConicalGradient(static_cast<qreal>(cx0), static_cast<qreal>(cy1), static_cast<qreal>(startAngle2));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QConicalGradient::QConicalGradient(qreal,qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_initialize_1native__Lio_qt_gui_QConicalGradient_2DDD)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble cx0,
 jdouble cy1,
 jdouble startAngle2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QConicalGradient::QConicalGradient(qreal,qreal,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].d = cx0;
        arguments[1].d = cy1;
        arguments[2].d = startAngle2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QConicalGradient_qreal_qreal_qreal, sizeof(QConicalGradient), typeid(QConicalGradient), false, &deleter_QConicalGradient, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QConicalGradient
void __qt_destruct_QConicalGradient(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QConicalGradient")
    reinterpret_cast<QConicalGradient*>(ptr)->~QConicalGradient();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QConicalGradient::angle()const
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_angle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::angle()const", __qt_this)
        qreal __qt_return_value = __qt_this->angle();
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QConicalGradient::center()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_center_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::center()const", __qt_this)
        QPointF __qt_return_value = __qt_this->center();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QConicalGradient::setAngle(qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setAngle_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble angle0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setAngle(qreal)", __qt_this)
        __qt_this->setAngle(static_cast<qreal>(angle0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::setCenter(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setCenter_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID center0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setCenter(QPointF)", __qt_this)
        const QPointF& __qt_center0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(center0);
        __qt_this->setCenter(__qt_center0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QConicalGradient::setCenter(qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_setCenter_1native_1qreal_1qreal__JDD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble x0,
 jdouble y1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QConicalGradient::setCenter(qreal,qreal)", __qt_this)
        __qt_this->setCenter(static_cast<qreal>(x0), static_cast<qreal>(y1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QConicalGradient(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QConicalGradient* copy = static_cast<const QConicalGradient*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QConicalGradient(copy->center(), copy->angle());
    }else{
        return new(placement) QConicalGradient();
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QConicalGradient_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QConicalGradient *__qt_this = QtJambiAPI::objectFromNativeId<QConicalGradient>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QConicalGradient(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QConicalGradient>("QConicalGradient", "io/qt/gui/QConicalGradient");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QConicalGradient, {
        ConstructorInfo(&__qt_construct_QConicalGradient, nullptr)
       ,ConstructorInfo(&__qt_construct_QConicalGradient_cref_QConicalGradient, "Lio/qt/gui/QConicalGradient;")
       ,ConstructorInfo(&__qt_construct_QConicalGradient_cref_QPointF_qreal, "Lio/qt/core/QPointF;D")
       ,ConstructorInfo(&__qt_construct_QConicalGradient_qreal_qreal_qreal, "DDD")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QConicalGradient);
    registerMetaType<QConicalGradient>("QConicalGradient", &custom_constructor_QConicalGradient);
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QGradient), typeId, [](void *ptr, qintptr& offset) -> bool {
            QGradient *object = reinterpret_cast<QGradient *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type() == QGradient::ConicalGradient;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
